Simmate Visualization
---------------------

:warning: This module is at the planning stage. We plan for it to be be extremely similar to pymatgen.vis's module. It will have classes for plotting and 3d modeling. Currently, it can only create a minimal structure using Blender.
